# Config file for the magics package
# Defines the following variables:
#
#  MAGICS_INCLUDE_DIRS - include directories
#  MAGICS_DEFINITIONS  - preprocessor definitions
#  MAGICS_LIBRARIES    - libraries to link against
#
# Also defines magics third-party library dependencies:
#  MAGICS_TPLS             - package names of  third-party library dependencies
#  MAGICS_TPL_INCLUDE_DIRS - include directories
#  MAGICS_TPL_DEFINITIONS  - preprocessor definitions
#  MAGICS_TPL_LIBRARIES    - libraries to link against

# compute paths

get_filename_component(MAGICS_CMAKE_DIR "${CMAKE_CURRENT_LIST_FILE}" PATH)

set( MAGICS_SELF_INCLUDE_DIRS "${MAGICS_CMAKE_DIR}/../../../include" )
set( MAGICS_SELF_DEFINITIONS  "$<$<NOT:$<CONFIG:Debug>>:QT_NO_DEBUG>;QT_GUI_LIB;QT_XML_LIB;QT_CORE_LIB" )
set( MAGICS_SELF_LIBRARIES    "MagPlus" )

set( MAGICS_TPLS             "grib_api;spot;odb_api;EXPAT;NetCDF;PangoCairo;Proj4;EMOS" )

set( MAGICS_TPL_INCLUDE_DIRS "/usr/include;/usr/include;/usr/include/hdf5/serial;/usr/include/pango-1.0;/usr/include/cairo;/usr/include/glib-2.0;/usr/lib/x86_64-linux-gnu/glib-2.0/include;/usr/include/pixman-1;/usr/include/freetype2;/usr/include/libpng12;/usr/include" )
set( MAGICS_TPL_DEFINITIONS  "" )
set( MAGICS_TPL_LIBRARIES    "/usr/lib/x86_64-linux-gnu/libexpat.so;debug;optimized;/usr/lib/libnetcdf.so;/usr/lib/libnetcdf_c++.so;/usr/lib/x86_64-linux-gnu/hdf5/serial/lib/libhdf5_hl.so;/usr/lib/x86_64-linux-gnu/hdf5/serial/lib/libhdf5.so;/usr/lib/x86_64-linux-gnu/libpthread.so;/usr/lib/x86_64-linux-gnu/libz.so;/usr/lib/x86_64-linux-gnu/libdl.so;/usr/lib/x86_64-linux-gnu/libm.so;/usr/lib/x86_64-linux-gnu/hdf5/serial/lib/libhdf5.so;/usr/lib/x86_64-linux-gnu/libpthread.so;/usr/lib/x86_64-linux-gnu/libz.so;/usr/lib/x86_64-linux-gnu/libdl.so;/usr/lib/x86_64-linux-gnu/libm.so;/usr/lib/x86_64-linux-gnu/hdf5/serial/lib/libhdf5_cpp.so;/usr/lib/x86_64-linux-gnu/hdf5/serial/lib/libhdf5.so;/usr/lib/x86_64-linux-gnu/libpthread.so;/usr/lib/x86_64-linux-gnu/libz.so;/usr/lib/x86_64-linux-gnu/libdl.so;/usr/lib/x86_64-linux-gnu/libm.so;/usr/lib/x86_64-linux-gnu/hdf5/serial/lib/libhdf5_hl.so;/usr/lib/x86_64-linux-gnu/hdf5/serial/lib/libhdf5.so;/usr/lib/x86_64-linux-gnu/libpthread.so;/usr/lib/x86_64-linux-gnu/libz.so;/usr/lib/x86_64-linux-gnu/libdl.so;/usr/lib/x86_64-linux-gnu/libm.so;pangocairo-1.0;pango-1.0;gobject-2.0;glib-2.0;cairo;/usr/lib/libproj.so;/usr/lib/x86_64-linux-gnu/libemosR64.so;/usr/lib/gcc/x86_64-linux-gnu/4.9/libgfortran.so" )

# include paths as absolute paths
set( MAGICS_INCLUDE_DIRS "" )
foreach( path ${MAGICS_SELF_INCLUDE_DIRS} )
	get_filename_component( abspath ${path} ABSOLUTE )
	list( APPEND MAGICS_INCLUDE_DIRS ${abspath} )
endforeach()
list( APPEND MAGICS_INCLUDE_DIRS ${MAGICS_TPL_INCLUDE_DIRS} )

set( MAGICS_DEFINITIONS      ${MAGICS_SELF_DEFINITIONS} ${MAGICS_TPL_DEFINITIONS} )
set( MAGICS_LIBRARIES        ${MAGICS_SELF_LIBRARIES}  ${MAGICS_TPL_LIBRARIES} )


if( EXISTS ${MAGICS_CMAKE_DIR}/magics-import.cmake )
  set( MAGICS_IMPORT_FILE "${MAGICS_CMAKE_DIR}/magics-import.cmake" )
  debug_var( MAGICS_IMPORT_FILE )
  include( ${MAGICS_IMPORT_FILE} )
endif()

# insert definitions for IMPORTED targets

if( NOT magics_BINARY_DIR )

	set( IS_BUILD_DIR_EXPORT OFF )

	if( IS_BUILD_DIR_EXPORT )
		include( "/srv/build/magics++/magics++-2.22.7.dfsg.1/debian/build/magics-targets.cmake" OPTIONAL )
	else()
		include( "${MAGICS_CMAKE_DIR}/magics-targets.cmake" )
	endif()

endif()

# here goes the imports of the TPL's

include( ${CMAKE_CURRENT_LIST_FILE}.tpls OPTIONAL )

# publish this file as imported

set( MAGICS_IMPORT_FILE ${CMAKE_CURRENT_LIST_FILE} )
mark_as_advanced( MAGICS_IMPORT_FILE )

